﻿using System;
using System.Globalization;
using System.IO;
using System.Threading.Tasks;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace NTmdb.TestProject
{
    /// <summary>
    ///     This is a test class for TmdbAuthenticationTokenTest and is intended
    ///     to contain all TmdbAuthenticationTokenTest Unit Tests
    /// </summary>
    [TestClass]
    public class TmdbAuthenticationTokenTest
    {
        /// <summary>
        ///     A test for TmdbAuthenticationToken Constructor
        /// </summary>
        [TestMethod]
        public void TmdbAuthenticationTokenConstructorTest()
        {
            var target = new TmdbAuthenticationToken();
            Assert.IsNotNull( target );
        }

        /// <summary>
        ///     A test for GetExpireDate
        /// </summary>
        [TestMethod]
        public void GetExpireDateTest()
        {
            var target = new TmdbAuthenticationToken();
            target.ExpiresAtString = DateTime.Now.ToString( "yyyy-MM-dd" );
            const string dateTimePattern = "yyyy-MM-dd";
            target.ExpiresAtString = "2010-09-10";
            var expected = DateTime.ParseExact( target.ExpiresAtString, dateTimePattern, CultureInfo.InvariantCulture );
            var actual = target.GetExpireDate( dateTimePattern );
            Assert.AreEqual( expected.Year, actual.Value.Year );
        }

        /// <summary>
        ///     A test for GetIsExpired
        /// </summary>
        [TestMethod]
        public void GetIsExpiredTest()
        {
            var target = new TmdbAuthenticationToken();
            target.ExpiresAtString = DateTime.Now.ToString( "yyyy-MM-dd" );
            const string dateTimePattern = "yyyy-MM-dd";
            target.ExpiresAtString = "2010-09-10";
            var actual = target.GetIsExpired( dateTimePattern );
            Assert.AreEqual( true, actual );
        }

        /// <summary>
        ///     A test for ExpiresAtString
        /// </summary>
        [TestMethod]
        public void ExpiresAtStringTest()
        {
            var target = new TmdbAuthenticationToken();
            string expected = Guid.NewGuid().ToString();
            target.ExpiresAtString = expected;
            string actual = target.ExpiresAtString;
            Assert.AreEqual( expected, actual );
        }

        /// <summary>
        ///     A test for Success
        /// </summary>
        [TestMethod]
        public void SuccessTest()
        {
            var target = new TmdbAuthenticationToken();
            bool expected = new Random().Next( 0, Int32.MaxValue ) % 2 == 0;
            target.Success = expected;
            bool actual = target.Success;
            Assert.AreEqual( expected, actual );
        }

        /// <summary>
        ///     A test for Token
        /// </summary>
        [TestMethod]
        public void TokenTest()
        {
            var target = new TmdbAuthenticationToken();
            string expected = Guid.NewGuid().ToString();
            target.Token = expected;
            string actual = target.Token;
            Assert.AreEqual( expected, actual );
        }

        /// <summary>
        ///     A test for Serialize & Deserialize
        /// </summary>
        [TestMethod]
        [DeploymentItem(@"..\..\TestData\authenticationToken.json.txt")]
        public async Task SerializeDeserializeTest()
        {
            var target = new TmdbAuthenticationToken();
            var jsonContent = File.ReadAllText("authenticationToken.json.txt");
            var actual = await target.DeserializeJson<TmdbAuthenticationToken>(jsonContent);

            Assert.AreEqual("2013-07-19 07:04:31 UTC", actual.ExpiresAtString);
            Assert.AreEqual(true, actual.Success);
            Assert.AreEqual("e85f380c35663eb94ab6bab8624b0be8d6a751aa", actual.Token);
        }
    }
}