﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Threading.Tasks;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace NTmdb.TestProject
{
    /// <summary>
    ///     This is a test class for TmdbReleasesTest and is intended
    ///     to contain all TmdbReleasesTest Unit Tests
    /// </summary>
    [TestClass]
    public class TmdbReleasesTest
    {
        /// <summary>
        ///     A test for TmdbReleases Constructor
        /// </summary>
        [TestMethod]
        public void TmdbReleasesConstructorTest()
        {
            var target = new TmdbReleases();
            Assert.IsNotNull( target );
        }

        /// <summary>
        ///     A test for Id
        /// </summary>
        [TestMethod]
        public void IdTest()
        {
            var target = new TmdbReleases();
            int expected = new Random().Next( 0, Int32.MaxValue );
            int actual;
            target.Id = expected;
            actual = target.Id;
            Assert.AreEqual( expected, actual );
        }

        /// <summary>
        ///     A test for Releases
        /// </summary>
        [TestMethod]
        public void ReleasesTest()
        {
            var target = new TmdbReleases();
            var expected = new List<TmdbRelease>();
            List<TmdbRelease> actual;
            target.Releases = expected;
            actual = target.Releases;
            Assert.AreSame( expected, actual );
        }

        /// <summary>
        ///     A test for Serialize & Deserialize
        /// </summary>
        [TestMethod]
        [DeploymentItem(@"..\..\TestData\movieReleases.json.txt")]
        public async Task SerializeDeserializeTest()
        {
            var target = new TmdbReleases();
            var jsonContent = File.ReadAllText("movieReleases.json.txt");
            var actual = await target.DeserializeJson<TmdbReleases>(jsonContent);

            Assert.AreEqual(550, actual.Id);
            Assert.AreEqual(4, actual.Releases.Count);

            Assert.AreEqual("US", actual.Releases[0].Iso3166_1);
            Assert.AreEqual("R", actual.Releases[0].Certification);
            Assert.AreEqual("1999-10-14", actual.Releases[0].ReleaseDate);

            Assert.AreEqual("DE", actual.Releases[1].Iso3166_1);
            Assert.AreEqual("18", actual.Releases[1].Certification);
            Assert.AreEqual("1999-11-10", actual.Releases[1].ReleaseDate);

            Assert.AreEqual("TR", actual.Releases[2].Iso3166_1);
            Assert.AreEqual("", actual.Releases[2].Certification);
            Assert.AreEqual("1999-12-10", actual.Releases[2].ReleaseDate);

            Assert.AreEqual("IT", actual.Releases[3].Iso3166_1);
            Assert.AreEqual("VM14", actual.Releases[3].Certification);
            Assert.AreEqual("1999-10-29", actual.Releases[3].ReleaseDate);
        }
    }
}